==> zzyj-financeintegration-api-3.0.0-20220831.064756-55-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMSalaryPayApplyDetailVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMSalaryPayApplyDetailVO implements Serializable {
    /**
     * 基础消息信息处理队列（修改数据）
     */
    public static final String SALARY_PAY_RESULT_MESSAGE = "salaryPayResult";

    /**
     * 主键
     */
    private String id;

    /**
     * PM单据ID（）
     */
    private String salaryPayApplyId;


    /**
     * 姓名
     */
    private String workerName;


    /**
     * 性别
     */
    private String workerSex;

    /**
     * 账号
     */
    private String workerAccountNum;

    /**
     * 金额
     */
    private BigDecimal workerApplyTaxMny;//申请金额


    /**
     * 开户行
     */
    private String workerBankName;

    /**
     * 联行号
     */
    private String interBankNum;

    /**
     * 身份证
     */
    private String workerIdCard;

    /**
     * 手机号
     */
    private String workerPhone;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */

    private String payState;

    /**
     * 修改时间
     */
    private String updateTime;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public String getWorkerSex() {
        return workerSex;
    }

    public void setWorkerSex(String workerSex) {
        this.workerSex = workerSex;
    }

    public String getWorkerAccountNum() {
        return workerAccountNum;
    }

    public void setWorkerAccountNum(String workerAccountNum) {
        this.workerAccountNum = workerAccountNum;
    }

    public BigDecimal getWorkerApplyTaxMny() {
        return workerApplyTaxMny;
    }

    public void setWorkerApplyTaxMny(BigDecimal workerApplyTaxMny) {
        this.workerApplyTaxMny = workerApplyTaxMny;
    }

    public String getWorkerBankName() {
        return workerBankName;
    }

    public void setWorkerBankName(String workerBankName) {
        this.workerBankName = workerBankName;
    }

    public String getInterBankNum() {
        return interBankNum;
    }

    public void setInterBankNum(String interBankNum) {
        this.interBankNum = interBankNum;
    }

    public String getWorkerIdCard() {
        return workerIdCard;
    }

    public void setWorkerIdCard(String workerIdCard) {
        this.workerIdCard = workerIdCard;
    }

    public String getWorkerPhone() {
        return workerPhone;
    }

    public void setWorkerPhone(String workerPhone) {
        this.workerPhone = workerPhone;
    }

    public String getPayState() {
        return payState;
    }

    public void setPayState(String payState) {
        this.payState = payState;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }
}

==> zzyj-financeintegration-api-3.0.0-20251015.082513-127-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMSalaryPayApplyDetailVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMSalaryPayApplyDetailVO implements Serializable {
    /**
     * 基础消息信息处理队列（修改数据）
     */
    public static final String SALARY_PAY_RESULT_MESSAGE = "salaryPayResult";

    /**
     * 主键
     */
    private String id;

    /**
     * PM单据ID（）
     */
    private String salaryPayApplyId;


    /**
     * 姓名
     */
    private String workerName;


    /**
     * 性别
     */
    private String workerSex;

    /**
     * 账号
     */
    private String workerAccountNum;

    /**
     * 金额
     */
    private BigDecimal workerApplyTaxMny;//申请金额


    /**
     * 开户行
     */
    private String workerBankName;

    /**
     * 联行号
     */
    private String interBankNum;

    /**
     * 身份证
     */
    private String workerIdCard;

    /**
     * 手机号
     */
    private String workerPhone;

    /**
     * 开户行省份
     */
    private String workerBankProvince;

    /**
     * 状态
     * 0-待支付、1-银行支付中、2-支付成功、3-支付失败
     * PM系统新增中间表数据时，设置初始状态为“待支付”
     */

    private String payState;

    /**
     * 修改时间
     */
    private String updateTime;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSalaryPayApplyId() {
        return salaryPayApplyId;
    }

    public void setSalaryPayApplyId(String salaryPayApplyId) {
        this.salaryPayApplyId = salaryPayApplyId;
    }

    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public String getWorkerSex() {
        return workerSex;
    }

    public void setWorkerSex(String workerSex) {
        this.workerSex = workerSex;
    }

    public String getWorkerAccountNum() {
        return workerAccountNum;
    }

    public void setWorkerAccountNum(String workerAccountNum) {
        this.workerAccountNum = workerAccountNum;
    }

    public BigDecimal getWorkerApplyTaxMny() {
        return workerApplyTaxMny;
    }

    public void setWorkerApplyTaxMny(BigDecimal workerApplyTaxMny) {
        this.workerApplyTaxMny = workerApplyTaxMny;
    }

    public String getWorkerBankName() {
        return workerBankName;
    }

    public void setWorkerBankName(String workerBankName) {
        this.workerBankName = workerBankName;
    }

    public String getInterBankNum() {
        return interBankNum;
    }

    public void setInterBankNum(String interBankNum) {
        this.interBankNum = interBankNum;
    }

    public String getWorkerIdCard() {
        return workerIdCard;
    }

    public void setWorkerIdCard(String workerIdCard) {
        this.workerIdCard = workerIdCard;
    }

    public String getWorkerPhone() {
        return workerPhone;
    }

    public void setWorkerPhone(String workerPhone) {
        this.workerPhone = workerPhone;
    }

    public String getPayState() {
        return payState;
    }

    public void setPayState(String payState) {
        this.payState = payState;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getWorkerBankProvince() {
        return workerBankProvince;
    }

    public void setWorkerBankProvince(String workerBankProvince) {
        this.workerBankProvince = workerBankProvince;
    }
}
